==> haskell-mwc-random-0.15.0.2-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mwc-random
version:              0.15.0.2
visibility:           public
id:                   mwc-random-0.15.0.2-ISIkInjEApt6bf7uADxNH9
key:                  mwc-random-0.15.0.2-ISIkInjEApt6bf7uADxNH9
license:              BSD-3-Clause
copyright:            2009, 2010, 2011 Bryan O'\''Sullivan
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/mwc-random
synopsis:             Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.

    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.

    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.

category:             Math, Statistics
abi:                  d7c036db97200098b583e7b5449078bb
exposed:              True
exposed-modules:
    System.Random.MWC System.Random.MWC.CondensedTable
    System.Random.MWC.Distributions System.Random.MWC.SeedSource

import-dirs:          /usr/lib/ghc-9.0.1/site-local/mwc-random-0.15.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/mwc-random-0.15.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/mwc-random-0.15.0.2
hs-libraries:         HSmwc-random-0.15.0.2-ISIkInjEApt6bf7uADxNH9
depends:
    base-4.15.0.0 math-functions-0.3.4.2-JahvwwzxymhIbwMpzOeuPn
    primitive-0.7.2.0-H9HP2FbaY5C1JlRHDKja9P
    random-1.2.0-EebvJ7tOx2vL3JJA3HPSmW time-1.9.3
    vector-0.12.3.0-De9qFY1R3VUAgnLs7G2KGQ

haddock-interfaces:   /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html:         /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mwc-random-0.15.0.2-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mwc-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mwc-random
version:              0.15.0.2
visibility:           public
id:                   mwc-random-0.15.0.2-Ih5prQdDgE3K0iNq8PJpfa
key:                  mwc-random-0.15.0.2-Ih5prQdDgE3K0iNq8PJpfa
license:              BSD-3-Clause
copyright:            2009, 2010, 2011 Bryan O'\''Sullivan
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/mwc-random
synopsis:             Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.

    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.

    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.

category:             Math, Statistics
abi:                  912d4abbcccfccf03baaa9d96ab3bdd0
exposed:              True
exposed-modules:
    System.Random.MWC System.Random.MWC.CondensedTable
    System.Random.MWC.Distributions System.Random.MWC.SeedSource

import-dirs:          /usr/lib/ghc-9.0.1/site-local/mwc-random-0.15.0.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/mwc-random-0.15.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/mwc-random-0.15.0.2
hs-libraries:         HSmwc-random-0.15.0.2-Ih5prQdDgE3K0iNq8PJpfa
depends:
    base-4.15.0.0 math-functions-0.3.4.2-9JsqoFcdgzc18rEpAEl9So
    primitive-0.7.2.0-CRVMUr03rWA6mteLYF9DMr
    random-1.2.0-Ir3cbNe9SLzCZxfRqPgBqL time-1.9.3
    vector-0.12.3.0-9DZQGy1wtT04xhfTzc80b4

haddock-interfaces:   /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html:         /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
